# cocheck
🌟 A simple connectivity checker 🔌
## Installation
The most simplest way to install:
```
pip install cocheck
```
## How to use
```
usage: main.py [-h] --url URL --type [GET,POST] --ssl [yes,no]
```
